==> mcalendar_0.5.0-5.tar.gz: mcalendar-0.5.0/make.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published
## by the Free Software Foundation; version 2 only.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
import py2deb

if __name__ == "__main__":
    try:
        os.chdir(os.path.dirname(sys.argv[0]))
    except:
        pass

    p=py2deb.Py2deb("mcalendar")
    p.description="mCalendar is a small calendar application specially designed for maemo internet tablet. You can use it without a stylus, and sync it with Google Calendar."
    p.author="Benoît HERVIER"
    p.mail="khertan@khertan.net"
    p.depends = "python2.5-hildon,python2.5-gtk2,python2.5-cairo,python2.5-osso,python2.5-xml, python-gdata, python-sqlite, python-dateutil"
    p.section="user/office"
    p.arch="any"
    p.urgency="low"
    p.distribution="diablo"
    p.repository="extras-devel"
    p["/usr/bin"] = ["mcalendar.launch",]
    p["/usr/share/dbus-1/services"] = ["mcalendar.service",]
    p["/usr/share/pixmaps"] = ["mcalendar.png",]
    p["/usr/share/applications/hildon"] = ["mcalendar.desktop",]
    p["/usr/lib/python2.5/site-packages"] = [
      "mcalendar_framework.py","mcalendar_framework.pyo","mcalendar_framework.pyc",]
    p["/usr/lib/mcalendar"] = [
      "agenda_view.py","agenda_view.pyo",
      "mcalendar_sync.pyc","mcalendar_sync.pyo","mcalendar_sync.py",
      "mcalendar_ui.py","mcalendar_ui.pyo",#"mcalendar_ui.pyc",
      "mcalendar_util.py","mcalendar_util.pyo","mcalendar_util.pyc",
      "mcalendar_prefs.py","mcalendar_prefs.pyo","mcalendar_prefs.pyc",
      "mcalendar_sync.py","mcalendar_sync.pyo","mcalendar_sync.pyc",
      "make.py",

      "ui/accept.png","ui/info.png","ui/refresh.png",
      "ui/add.png","ui/mcalendar.glade","ui/remove.png",
      "ui/alarm.png","ui/mcalendar.png","ui/repeat.png",
      "ui/back.png","ui/mcalendar32.png","ui/search.png",
      "ui/calendar_date.png","ui/mcalendar48.png",#"throbber-medium.gif",
      "ui/calendar_empty.png","ui/month.png","ui/today.png",
      "ui/clock.png","ui/mprefs.glade","ui/warning.png",
      "ui/favorite.png","ui/next.png","ui/week.png",
      "ui/help.png","ui/people.png",]

    print p
    r = p.generate("0.5.0","5",changelog=" * Total rewrite",tar=True,dsc=True,changes=True,build=False,src=True)
    print r

#scp *0.5.0-5* khertan@garage.maemo.org:/var/www/extras-devel/incoming-builder/diablo

==> mcalendar_0.5.3-1.tar.gz: mcalendar-0.5.3/make.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published
## by the Free Software Foundation; version 2 only.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
import py2deb

if __name__ == "__main__":
    try:
        os.chdir(os.path.dirname(sys.argv[0]))
    except:
        pass

    p=py2deb.Py2deb("mcalendar")
    p.description="mCalendar is a small calendar application specially designed for maemo internet tablet. You can use it without a stylus, and sync it with Google Calendar."
    p.author="Benoît HERVIER"
    p.mail="khertan@khertan.net"
    p.depends = "python2.5-hildon,python2.5-gtk2,python2.5-cairo,python2.5-osso,python2.5-xml, python-gdata, python-sqlite, python-dateutil"
    p.section="user/office"
    p.arch="any"
    p.urgency="low"
    p.distribution="diablo"
    p.repository="extras-devel"
    p["/usr/bin"] = ["mcalendar.launch",]
    p["/usr/share/dbus-1/services"] = ["mcalendar.service",]
    p["/usr/share/pixmaps"] = ["mcalendar.png",]
    p["/usr/share/applications/hildon"] = ["mcalendar.desktop",]
    p["/usr/lib/python2.5/site-packages"] = [
      "mcalendar_framework.py","mcalendar_framework.pyo","mcalendar_framework.pyc",]
    p["/usr/lib/mcalendar"] = [
      "agenda_view.py","agenda_view.pyo",
      "mcalendar_sync.pyc","mcalendar_sync.pyo","mcalendar_sync.py",
      "mcalendar_ui.py","mcalendar_ui.pyo",#"mcalendar_ui.pyc",
      "mcalendar_util.py","mcalendar_util.pyo","mcalendar_util.pyc",
      "mcalendar_prefs.py","mcalendar_prefs.pyo","mcalendar_prefs.pyc",
      "mcalendar_sync.py","mcalendar_sync.pyo","mcalendar_sync.pyc",
      "make.py",

      "ui/accept.png","ui/info.png","ui/refresh.png",
      "ui/add.png","ui/mcalendar.glade","ui/remove.png",
      "ui/alarm.png","ui/mcalendar.png","ui/repeat.png",
      "ui/back.png","ui/mcalendar32.png","ui/search.png",
      "ui/calendar_date.png","ui/mcalendar48.png",#"throbber-medium.gif",
      "ui/calendar_empty.png","ui/month.png","ui/today.png",
      "ui/clock.png","ui/mprefs.glade","ui/warning.png",
      "ui/favorite.png","ui/next.png","ui/week.png",
      "ui/help.png","ui/people.png",]

    print p
    r = p.generate("0.5.3","1",changelog=" * Fix a bug on Autosync",tar=True,dsc=True,changes=True,build=False,src=True)
    print r

#scp *0.5.3-1* khertan@garage.maemo.org:/var/www/extras-devel/incoming-builder/diablo
